@@ -4,7 +4,9 @@
 
 #include <stdio.h>
 #include <stdlib.h>
+#ifndef __USE_GNU
 #define __USE_GNU		/* for strcasestr() */
+#endif
 #include <string.h>
 #include <locale.h>
 #include <libintl.h>
@@ -91,6 +93,7 @@ void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
 	// translated. Otherwise, only Line X should be translated and the
 	// ASCII-only fonts should be given bad scores in the scoring code below.
 	// (the best scores going to fonts that support both)
+	
 	if (strcmp("Zapfino", family) && strcmp("Elvish Ring NFI", family) && ((charset_works(font, gettext("qx")) && charset_works(font, gettext("QX")))	// Line X
 									       || (charset_works(font, gettext("qy")) && charset_works(font, gettext("QY")))	// Line Y
 	    ))
@@ -118,6 +121,9 @@ void loadfont_callback(SDL_Surface * screen, const char *restrict const dir,
 	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("017"));	// digits
 	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("O0"));	// distinct circle-like characters
 	  user_font_styles[num_font_styles]->score += charset_works(font, gettext("1Il|"));	// distinct line-like characters
+#ifdef OLPC_XO
+	  user_font_styles[num_font_styles]->score += charset_works(font, "\xc3\x97\xc3\xb7");	// multiply and divide
+#endif
 	  num_font_styles++;
 //printf("Accepted: %s, %s, %s, score(%d)\n", files[i].str, family, style, user_font_styles[num_font_styles]->score);
 	  files[i].str = NULL;	// so free() won't crash -- we stole the memory
@@ -271,7 +277,7 @@ void tp_ftw(SDL_Surface * screen, char *restrict const dir, unsigned dirlen,
   show_progress_bar(screen);
   dir[dirlen] = '\0';		// repair it (clobbered for stat() call above)
 
-  if (file_names)
+  if (1 || file_names)  // Now ALWAYS calling callback function, so stamp loader can notice top-level directories (even if there are only subdirs, and no files, inside) -bjk 2007.05.16
   {
 // let callee sort and keep the string
 #if 0
