@@ -3,7 +3,9 @@
 */
 
 #include <stdio.h>
+#ifndef __USE_GNU
 #define __USE_GNU		/* for strcasestr() */
+#endif
 #include <string.h>
 #include <stdlib.h>
 #include <locale.h>
@@ -81,6 +83,12 @@ unsigned text_size = 4;		// initial text size
    TTF_OpenFont() with the filename of a font that doesn't exist. This
    is an old and well documented bug that is fixed in CVS.
 */
+
+/* FIXME: SDL_ttf is up to 2.0.8, so we can probably fully remove this
+   -bjk 2007.06.05 */
+
+/*
+
 TTF_Font *BUGFIX_TTF_OpenFont206(const char *const file, int ptsize)
 {
   FILE *fp;
@@ -96,10 +104,9 @@ TTF_Font *BUGFIX_TTF_OpenFont206(const char *const file, int ptsize)
 #undef TTF_OpenFont
   return TTF_OpenFont(file, ptsize);
 }
+*/
 
-
-#define TTF_OpenFont    BUGFIX_TTF_OpenFont206
-
+/* #define TTF_OpenFont    BUGFIX_TTF_OpenFont206 */
 
 TTF_Font *try_alternate_font(int size)
 {
@@ -168,6 +175,7 @@ TTF_Font *load_locale_font(TTF_Font * fallback, int size)
 	putenv((char *) "LANG=C");
 	putenv((char *) "OUTPUT_CHARSET=C");
 	setlocale(LC_ALL, "C");
+	ctype_utf8();
 
 	set_current_language();
       }
