@@ -48,9 +48,12 @@ extern int font_socket_fd;
 extern int no_system_fonts;
 extern int was_bad_font;
 
-
+/* FIXME: SDL_ttf is up to 2.0.8, so we can probably fully remove this;
+   -bjk 2007.06.05 */
+/*
 TTF_Font *BUGFIX_TTF_OpenFont206(const char *const file, int ptsize);
 #define TTF_OpenFont    BUGFIX_TTF_OpenFont206
+*/
 
 TTF_Font *try_alternate_font(int size);
 TTF_Font *load_locale_font(TTF_Font * fallback, int size);
@@ -79,7 +82,11 @@ extern unsigned text_size;
 // nice progression (alternating 33% and 25%) 9 12 18 24 36 48 72 96 144 192
 // commonly hinted sizes seem to be: 9, 10, 12, 14, 18, 20 (less so), 24
 // reasonable: 9,12,18... and 10,14,18...
-static int text_sizes[] = { 9, 12, 18, 24, 36, 48,
+static int text_sizes[] = {
+#ifndef OLPC_XO
+  9,
+#endif
+  12, 18, 24, 36, 48,
   56, 64, 96, 112, 128, 160
 };				// point sizes
 
