@@ -4,17 +4,21 @@
   For Tux Paint
   Language-related functions
 
-  Copyright (c) 2002-2006 by Bill Kendrick and others
+  Copyright (c) 2002-2007 by Bill Kendrick and others
   bill@newbreedsoftware.com
-  http://www.newbreedsoftware.com/tuxpaint/
+  http://www.tuxpaint.org/
 
-  $Id: i18n.h,v 1.13 2006/10/11 07:54:09 wkendrick Exp $
+  $Id: i18n.h,v 1.18 2007/04/26 20:13:47 wkendrick Exp $
   
-  June 14, 2002 - October 11, 2006
+  June 14, 2002 - April 26, 2007
 */
 
 
 #ifndef I18N_H
+#define I18N_H
+
+#include <stdio.h>
+
 
 /* Possible languages: */
 
@@ -60,6 +64,7 @@ enum
   LANG_KO,			/* Korean */
   LANG_KU,			/* Kurdish */
   LANG_LT,			/* Lithuanian */
+  LANG_LV,			/* Latvian */
   LANG_MS,			/* Malay */
   LANG_NB,			/* Norwegian Bokmal */
   LANG_NR,                      /* Ndebele */
@@ -78,9 +83,11 @@ enum
   LANG_SV,			/* Swedish */
   LANG_SW,			/* Swahili */
   LANG_TA,			/* Tamil */
+  LANG_TE,                      /* Telugu */
   LANG_TH,			/* Thai */
   LANG_TL,			/* Tagalog */
   LANG_TR,			/* Turkish */
+  LANG_TWI,			/* Twi */
   LANG_UK,			/* Ukrainian */
   LANG_VE,			/* Venda */
   LANG_VI,			/* Vietnamese */
@@ -118,10 +125,12 @@ extern const language_to_locale_struct language_to_locale_array[];
 
 void set_langstr(const char *s);
 void set_current_language(void);
+int get_current_language(void);
 void show_lang_usage(FILE * f, const char *const prg);
 void show_locale_usage(FILE * f, const char *const prg);
 void setup_language(const char *const prg);
 void do_locale_option(const char *const arg);
+void ctype_utf8(void);
 
 
 #endif
