@@ -4,7 +4,7 @@
 //
 //  Created by Darrell Walisser on Sat Mar 15 2003.
 //  Copyright (c) 2003 Darrell Walisser. All rights reserved.
-//  $Id: macosx_print.h,v 1.4 2006/08/27 21:00:55 wkendrick Exp $
+//  $Id: macosx_print.h,v 1.5 2007/06/12 05:29:25 mfuhrer Exp $
 //
 //  This program is free software; you can redistribute it and/or modify
 //  it under the terms of the GNU General Public License as published by
@@ -25,3 +25,18 @@
 #include "SDL.h"
 
 const char *SurfacePrint(SDL_Surface * surface, int showDialog);
+
+#ifdef OBJECTIVEC
+
+BOOL DisplayPageSetup();
+
+@interface PrintSheetController : NSObject
+{
+	bool displayPrintSetupSheet;
+	bool displayPrintSheet;
+}
+
+- 
+@end
+
+#endif OBJECTIVEC
