@@ -9,6 +9,7 @@
   http://www.newbreedsoftware.com/tuxpaint/
 
   June 17, 2002 - June 27, 2002
+  $Id: tip_tux.h,v 1.4 2006/08/27 21:00:55 wkendrick Exp $
 */
 
 
@@ -17,7 +18,8 @@
 
 /* What tuxes are available: */
 
-enum {
+enum
+{
   TUX_DEFAULT,
   TUX_KISS,
   TUX_BORED,
@@ -30,7 +32,7 @@ enum {
 
 /* Tux filenames: */
 
-const char * const tux_img_fnames[NUM_TIP_TUX] = {
+const char *const tux_img_fnames[NUM_TIP_TUX] = {
   DATA_PREFIX "images/tux/default.png",
   DATA_PREFIX "images/tux/kiss.png",
   DATA_PREFIX "images/tux/bored.png",
