@@ -9,13 +9,15 @@
   http://www.newbreedsoftware.com/tuxpaint/
 
   June 14, 2002 - September 14, 2004
+  $Id: titles.h,v 1.5 2006/08/27 21:00:55 wkendrick Exp $
 */
 
 
 
 /* What titles are available: */
 
-enum {
+enum
+{
   TITLE_NONE,
   TITLE_NOCOLORS,
   TITLE_TOOLS,
@@ -32,7 +34,7 @@ enum {
 
 /* Title names: */
 
-const char * const title_names[NUM_TITLES] = {
+const char *const title_names[NUM_TITLES] = {
   "",
   "",
   gettext_noop("Tools"),
@@ -44,4 +46,3 @@ const char * const title_names[NUM_TITLES] = {
   gettext_noop("Letters"),
   gettext_noop("Magic")
 };
-
