@@ -22,7 +22,7 @@
 /* Sept. 30, 2002 - Oct. 17, 2002 */
 /* Oct.  07, 2003 - added banding support */
 /*                - prints using 24-bit (not 32-bit) bitmap */
-/* $Id: win32_print.c,v 1.10 2006/08/27 21:00:55 wkendrick Exp $ */
+/* $Id: win32_print.c,v 1.11 2007/04/28 02:52:11 johnnypops Exp $ */
 
 #include <windows.h>
 #include <direct.h>
@@ -576,3 +576,29 @@ char *GetSystemFontDir(void)
   }
   return strdup("C:\\WINDOWS\\FONTS");
 }
+
+/*
+  Returns heap string containing user temp directory.
+  E.g. C:\Documents and Settings\jfp\Local Settings\Temp
+*/
+static char *GetUserTempDir(void)
+{
+  char *temp = getenv("TEMP");
+
+  if (!temp)
+  {
+    temp = "userdata";
+  }
+  return strdup(temp);
+}
+
+char *get_temp_fname(const char *const name)
+{
+  char f[512];
+  char *tempdir = GetUserTempDir();
+
+  snprintf(f, sizeof(f), "%s/%s", tempdir, name);
+  free(tempdir);
+  return strdup(f);
+}
+
